loutilities - Lou's utilities
===================================

This is a package with a few hopefully useful utilities.

* agegrade - provide age grading calculations (running)
* apikey - manage API keys for an application
* bfile - binary file handler
* configparser - enhanced ConfigParser, provides dict and keys are case sensitive
* csvu - csv and string utilities
* csvwt - write csv from various file types
* extconfigparser - extend ConfigParser.RawConfigParser option interpretation
* geo - utilities for lat / long and other geographic manipulation
* googleauth - oauth 2.0 for google APIs
* kmlutils - utilities for access to kml file
* namesplitter - name splitting method
* nesteddict - handle dict keys like d['a.b.c'] as d['a']['b']['c']
* renderrun - common functions for rendering information related to running
* tables - utilities for dataTables javascript support
    * tables-files - supporting files required for tables.py -- these need to be copied to project using tables.py
* textreader - read text out of various file types
* timeu - time methods
* transform - transformation methods
* wxextensions - extensions for wxPython widgets
* xmldict - xml / dict conversions, from http://code.activestate.com/recipes/573463-converting-xml-to-dictionary-and-back/

Command line scripts

* agegrade - update age grading table (running)
* apikey - create / update key for an application
* applytemplate - apply a template to files in a directory
* filtercsv - filter a csv file based on indicated filter
* makerst - make rst files as input for Sphinx documentation for a given package

License
-------

loutilities is licensed under the [Apache License, Version 2.0](http://www.apache.org/licenses/LICENSE-2.0)

